OciProxyChain

Trait OciProxyChain 

pub trait OciProxyChain<'c, S>
where S: Socket,
{ // Required methods fn list_images<'__proxy_params>( self, handle: u64, filter: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>; fn oci_fsck<'__proxy_params>( self, handle: u64, image: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>; fn inspect<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, ) -> Result<Chain<'c, S>>; fn tag<'__proxy_params>( self, handle: u64, manifest_digest: &'__proxy_params str, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>; fn untag<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>; fn compute_id<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, verity: Option<&'__proxy_params str>, bootable: bool, ) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn list_images<'__proxy_params>( self, handle: u64, filter: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn oci_fsck<'__proxy_params>( self, handle: u64, image: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn inspect<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn tag<'__proxy_params>( self, handle: u64, manifest_digest: &'__proxy_params str, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn untag<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn compute_id<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, verity: Option<&'__proxy_params str>, bootable: bool, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Implementations on Foreign Types

Source

impl<'c, S> OciProxyChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn list_images<'__proxy_params>( self, handle: u64, filter: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Source

fn oci_fsck<'__proxy_params>( self, handle: u64, image: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Source

fn inspect<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Source

fn tag<'__proxy_params>( self, handle: u64, manifest_digest: &'__proxy_params str, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Source

fn untag<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Source

fn compute_id<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, verity: Option<&'__proxy_params str>, bootable: bool, ) -> Result<Chain<'c, S>>

Implementors