RepositoryProxyChain

Trait RepositoryProxyChain 

pub trait RepositoryProxyChain<'c, S>
where S: Socket,
{ // Required methods fn init_repository<'__proxy_params>( self, path: &'__proxy_params str, algorithm: Option<&'__proxy_params str>, insecure: Option<bool>, ) -> Result<Chain<'c, S>>; fn open_repository<'__proxy_params>( self, path: Option<&'__proxy_params str>, user: Option<bool>, system: Option<bool>, ) -> Result<Chain<'c, S>>; fn close_repository(self, handle: u64) -> Result<Chain<'c, S>>; fn fsck( self, handle: u64, metadata_only: Option<bool>, ) -> Result<Chain<'c, S>>; fn gc( self, handle: u64, dry_run: bool, roots: Vec<String>, ) -> Result<Chain<'c, S>>; fn image_objects<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn init_repository<'__proxy_params>( self, path: &'__proxy_params str, algorithm: Option<&'__proxy_params str>, insecure: Option<bool>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn open_repository<'__proxy_params>( self, path: Option<&'__proxy_params str>, user: Option<bool>, system: Option<bool>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn close_repository(self, handle: u64) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn fsck(self, handle: u64, metadata_only: Option<bool>) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn gc( self, handle: u64, dry_run: bool, roots: Vec<String>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn image_objects<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Implementations on Foreign Types

Source

impl<'c, S> RepositoryProxyChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn init_repository<'__proxy_params>( self, path: &'__proxy_params str, algorithm: Option<&'__proxy_params str>, insecure: Option<bool>, ) -> Result<Chain<'c, S>>

Source

fn open_repository<'__proxy_params>( self, path: Option<&'__proxy_params str>, user: Option<bool>, system: Option<bool>, ) -> Result<Chain<'c, S>>

Source

fn close_repository(self, handle: u64) -> Result<Chain<'c, S>>

Source

fn fsck(self, handle: u64, metadata_only: Option<bool>) -> Result<Chain<'c, S>>

Source

fn gc( self, handle: u64, dry_run: bool, roots: Vec<String>, ) -> Result<Chain<'c, S>>

Source

fn image_objects<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>

Implementors