pub trait OciProxyChain<'c, S>where
S: Socket,{
// Required methods
fn list_images<'__proxy_params>(
self,
handle: u64,
filter: Option<&'__proxy_params str>,
) -> Result<Chain<'c, S>>;
fn oci_fsck<'__proxy_params>(
self,
handle: u64,
image: Option<&'__proxy_params str>,
) -> Result<Chain<'c, S>>;
fn inspect<'__proxy_params>(
self,
handle: u64,
image: &'__proxy_params str,
) -> Result<Chain<'c, S>>;
fn tag<'__proxy_params>(
self,
handle: u64,
manifest_digest: &'__proxy_params str,
name: &'__proxy_params str,
) -> Result<Chain<'c, S>>;
fn untag<'__proxy_params>(
self,
handle: u64,
name: &'__proxy_params str,
) -> Result<Chain<'c, S>>;
fn compute_id<'__proxy_params>(
self,
handle: u64,
image: &'__proxy_params str,
verity: Option<&'__proxy_params str>,
bootable: bool,
) -> Result<Chain<'c, S>>;
}Expand description
Extension trait for adding proxy calls to any chain.
This trait provides methods to add proxy calls to a chain of method calls.
Required Methods
Sourcefn list_images<'__proxy_params>(
self,
handle: u64,
filter: Option<&'__proxy_params str>,
) -> Result<Chain<'c, S>>
fn list_images<'__proxy_params>( self, handle: u64, filter: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn oci_fsck<'__proxy_params>(
self,
handle: u64,
image: Option<&'__proxy_params str>,
) -> Result<Chain<'c, S>>
fn oci_fsck<'__proxy_params>( self, handle: u64, image: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn inspect<'__proxy_params>(
self,
handle: u64,
image: &'__proxy_params str,
) -> Result<Chain<'c, S>>
fn inspect<'__proxy_params>( self, handle: u64, image: &'__proxy_params str, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn tag<'__proxy_params>(
self,
handle: u64,
manifest_digest: &'__proxy_params str,
name: &'__proxy_params str,
) -> Result<Chain<'c, S>>
fn tag<'__proxy_params>( self, handle: u64, manifest_digest: &'__proxy_params str, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.