pub trait RepositoryProxyChain<'c, S>where
S: Socket,{
// Required methods
fn init_repository<'__proxy_params>(
self,
path: &'__proxy_params str,
algorithm: Option<&'__proxy_params str>,
insecure: Option<bool>,
) -> Result<Chain<'c, S>>;
fn open_repository<'__proxy_params>(
self,
path: Option<&'__proxy_params str>,
user: Option<bool>,
system: Option<bool>,
) -> Result<Chain<'c, S>>;
fn close_repository(self, handle: u64) -> Result<Chain<'c, S>>;
fn fsck(
self,
handle: u64,
metadata_only: Option<bool>,
) -> Result<Chain<'c, S>>;
fn gc(
self,
handle: u64,
dry_run: bool,
roots: Vec<String>,
) -> Result<Chain<'c, S>>;
fn image_objects<'__proxy_params>(
self,
handle: u64,
name: &'__proxy_params str,
) -> Result<Chain<'c, S>>;
}Expand description
Extension trait for adding proxy calls to any chain.
This trait provides methods to add proxy calls to a chain of method calls.
Required Methods
Sourcefn init_repository<'__proxy_params>(
self,
path: &'__proxy_params str,
algorithm: Option<&'__proxy_params str>,
insecure: Option<bool>,
) -> Result<Chain<'c, S>>
fn init_repository<'__proxy_params>( self, path: &'__proxy_params str, algorithm: Option<&'__proxy_params str>, insecure: Option<bool>, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn open_repository<'__proxy_params>(
self,
path: Option<&'__proxy_params str>,
user: Option<bool>,
system: Option<bool>,
) -> Result<Chain<'c, S>>
fn open_repository<'__proxy_params>( self, path: Option<&'__proxy_params str>, user: Option<bool>, system: Option<bool>, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn close_repository(self, handle: u64) -> Result<Chain<'c, S>>
fn close_repository(self, handle: u64) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn fsck(self, handle: u64, metadata_only: Option<bool>) -> Result<Chain<'c, S>>
fn fsck(self, handle: u64, metadata_only: Option<bool>) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn gc(
self,
handle: u64,
dry_run: bool,
roots: Vec<String>,
) -> Result<Chain<'c, S>>
fn gc( self, handle: u64, dry_run: bool, roots: Vec<String>, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.
Sourcefn image_objects<'__proxy_params>(
self,
handle: u64,
name: &'__proxy_params str,
) -> Result<Chain<'c, S>>
fn image_objects<'__proxy_params>( self, handle: u64, name: &'__proxy_params str, ) -> Result<Chain<'c, S>>
Add a #method_name call to this chain.